.. Documentation master file

.. image:: ./_static/logo_plus.png
   :align: center
   :scale: 40


======================================
Welcome to Locan's documentation!
======================================

.. include:: ./source/introduction.rst


.. toctree::
   :maxdepth: 1
   :caption: Getting started
   :name: mastertoc_start

   ./source/installation
   ./tutorials/tutorials
   ./source/docker_readme_link


.. toctree::
   :maxdepth: 1
   :caption: User Guide
   :name: mastertoc_use

   ./source/design
   ./source/command_line_interface
   ./source/colormaps
   ./source/user_interface


.. toctree::
   :maxdepth: 1
   :caption: API Documentation
   :name: apitoc

   ./source/modules


.. toctree::
   :maxdepth: 1
   :caption: Project Details
   :name: mastertoc_project

   ./source/changes_link
   ./source/contributions
   ./source/license


.. toctree::
   :maxdepth: 1
   :caption: Developer Guide
   :name: mastertoc_develop

   ./source/documentation
   ./source/development


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
